pub struct Report {
pub version: String,
pub scanned_at: String,
pub scanned_paths: Vec<String>,
pub overall_score: u32,
pub overall_grade: Grade,
pub categories: Vec<CategoryReport>,
pub total_critical: usize,
pub total_high: usize,
pub total_medium: usize,
pub total_low: usize,
pub total_info: usize,
pub findings: Vec<Finding>,
}Expand description
Full security scan report.
Fields
version: StringTool version at scan time.
scanned_at: StringISO-8601 timestamp of when the scan was run.
scanned_paths: Vec<String>Path(s) that were scanned.
overall_score: u32Overall score across all categories (0–100).
overall_grade: GradeLetter grade.
categories: Vec<CategoryReport>Per-category breakdown.
total_critical: usizeTotal finding counts by severity.
total_high: usizetotal_medium: usizetotal_low: usizetotal_info: usizefindings: Vec<Finding>Flat list of all findings, sorted by severity (most severe first).
Implementations
Sourceimpl Report
impl Report
Sourcepub fn build(
findings: Vec<Finding>,
scanned_paths: Vec<String>,
version: impl Into<String>,
) -> Self
pub fn build( findings: Vec<Finding>, scanned_paths: Vec<String>, version: impl Into<String>, ) -> Self
Build a report from a flat list of findings produced by all scanners.
Sourcepub fn has_findings_at(&self, min: Severity) -> bool
pub fn has_findings_at(&self, min: Severity) -> bool
Returns true if the report has at least one finding at or above the
given severity threshold.